// Point3d.cpp: implementation of the Point3d class.
//
//////////////////////////////////////////////////////////////////////

#include "Point3d.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

Point3d::Point3d()
{
	x = 0.0;
	y = 0.0;
	z = 0.0;
}


Point3d::Point3d(const Point3d &pt)
{
	x = pt.x;
	y = pt.y;
	z = pt.z;
}

Point3d::Point3d(float x, float y, float z)
{
	this->x = x;
	this->y = y;
	this->z = z;
}


void Point3d::normalize()
{
	float som;

	som = (float)sqrt( x*x + y*y + z*z );

	if(som!=0)
	{
		x/=som;
		y/=som;
		z/=som;
	}
}

float Point3d::dist(Point3d pt1, Point3d pt2)
{
	float dx,dy,dz;

	dx = pt1.x-pt2.x;
	dy = pt1.y-pt2.y;
	dz = pt1.z-pt2.z;

	return (float)sqrt( dx*dx + dy*dy + dz*dz );
}

void Point3d::toFloat(float *tab)
{
	tab[0] = this->x;
	tab[1] = this->y;
	tab[2] = this->z;
	tab[3] = 1.0;
}

bool Point3d::operator <(Point3d pt)
{
	pt = pt;	// pour virer le warning
	return true;
}

bool Point3d::operator ==(Point3d pt)
{
	return (Point3d::dist(*this,pt)<Epsi);
}

Point3d Point3d::operator+(Point3d pt)
{
	Point3d tmp;

	tmp.x = this->x + pt.x;
	tmp.y = this->y + pt.y;
	tmp.z = this->z + pt.z;

	return tmp;
}

Point3d Point3d::operator-(Point3d pt)
{
	Point3d tmp;

	tmp.x = this->x - pt.x;
	tmp.y = this->y - pt.y;
	tmp.z = this->z - pt.z;

	return tmp;
}

void Point3d::operator+=(Vecteur v)
{
	this->x+=(float)v.dx;
	this->y+=(float)v.dy;
	this->z+=(float)v.dz;
}

void Point3d::operator*=(float coeff)
{
	this->x*=coeff;
	this->y*=coeff;
	this->z*=coeff;
}

void Point3d::operator+=(Point3d pt)
{
	this->x+=pt.x;
	this->y+=pt.y;
	this->z+=pt.z;
}

Vecteur Point3d::toVecteur(Point3d pt1, Point3d pt2)
{
	Vecteur v;
	v.dx = pt2.x - pt1.x;
	v.dy = pt2.y - pt1.y;
	v.dz = pt2.z - pt1.z;
	v.dw = 1.0;

	return v;
}
